@@ -1,5 +1,5 @@
 /*
- * $Id: output.c,v 1.80.4.4 2001/09/12 04:50:42 takesako Exp $
+ * $Id: output.c,v 1.80.4.6 2001/11/25 11:45:36 takesako Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -470,7 +470,13 @@ print_query(const char * qs, int w)
 	    printf("whence=%d", w);
 	    for (qs += strlen("whence="); isdigit(*qs); qs++);
 	} else {
-	    fputc(*(qs++), stdout);
+	    /* '"' is converted to entities "&quot;" */
+	    if (*qs == '"') {
+		fputs("&quot;", stdout);
+	    } else {
+		fputc(*qs, stdout);
+	    }
+	    qs++;
 	}
     }
     if (foo == 0) {
@@ -493,8 +499,14 @@ print_page_index(int n)
     sn = nmz_getenv("SCRIPT_NAME");
     dn = nmz_getenv("DOCUMENT_URI");
 
-    if(dn == NULL || *dn == '\0') 
-        dn=sn;
+    if(dn == NULL || *dn == '\0') {
+        dn = sn;
+    } else {
+	/* Delete characters after '?' for Lotus Domino Server R5.06a */
+	char *s;
+	for (s = dn; *s; s++)
+	    if (*s == '?') {*s = 0; break;}
+    }
 
     html_print(_("	<strong>Page:</strong> "));
 
